Sink

Struct Sink 

pub struct Sink { /* private fields */ }
A mock which can act as a data sink.

An instance of the mock can be constructed using the builder-style methods. Each item added by the builder methods will be returned in-order when data is written to the Sink.

Data can then be written to it using the embedded_io::Write or embedded_io_async::Write traits.

Blocking Example

use embedded_io::Write;

let mut mock_sink = Sink::new()
                        .accept_data(12)
                        .error(MockError(embedded_io::ErrorKind::BrokenPipe));

let data_bytes = "hello world!".as_bytes();
let res = mock_sink.write_all(data_bytes);
assert!(res.is_ok());

let res = mock_sink.write(data_bytes);
assert!(res.is_err_and(|e| e == MockError(embedded_io::ErrorKind::BrokenPipe)));

Async Example

use embedded_io_async::Write;

let mut mock_sink = Sink::new()
                        .accept_data(12)
                        .error(MockError(embedded_io::ErrorKind::BrokenPipe));

let data_bytes = "hello world!".as_bytes();
let res = mock_sink.write_all(data_bytes).await;
assert!(res.is_ok());

let res = mock_sink.write(data_bytes).await;
assert!(res.is_err_and(|e| e == MockError(embedded_io::ErrorKind::BrokenPipe)));

Implementations

Source

impl Sink

pub fn new() -> Self

Create a new empty Sink.

pub fn accept_data(self, n: usize) -> Self

Accept n bytes of data written to the Sink

pub fn error(self, e: MockError) -> Self

Add an error value to the Sink

pub fn closed(self) -> Self

Add a “connection closed” item to the Sink. When written, this will return Ok(0) to the caller (which might then result in an error value if they used the write_all method instead of write).

pub fn is_consumed(&self) -> bool

Check if all of the provided items were consumed

pub fn into_inner_data(self) -> Vec<u8>

Get the inner data that has been received from the writer

pub fn owned_handle(&mut self) -> OwnedHandle<'_, Self>

Get an OwnedHandle containing the Sink