OwnedHandle

Struct OwnedHandle 

pub struct OwnedHandle<'a, T> { /* private fields */ }
An owned handle to a Source or Sink.

It’s common to want an object which owns a type implementing Read or Write. But for testing purposes, the object under test can’t consume the mock, as we might want to verify some expectations on it afterwards. To get around this, an OwnedHandle can be taken from a Source or Sink, which also implements the underlying traits but only contains a mutable reference to the underlying mock.

Once the object under test is dropped, the mock object itself still exists and can be used to verify any expectations.

Example

use embedded_io::Write;

struct MySerialProtocol<T: embedded_io::Write> {
    serial: T,
}

impl<T: embedded_io::Write> MySerialProtocol<T> {
    fn hello(&mut self) -> Result<(), T::Error> {
        self.serial.write_all("hello".as_bytes())
    }
}

let mut mock_sink = Sink::new().accept_data(64);

// MySerialProtocol requires an owned `serial` type here
let mut my_protocol = MySerialProtocol {
    serial: mock_sink.owned_handle(),
};

let res = my_protocol.hello();
assert!(res.is_ok());

// Because we constructed `my_protocol` with an `OwnedHandle`, we still have access to the
// original `mock_sink` here to verify that the correct bytes were written.
let written = mock_sink.into_inner_data();
assert_eq!(written, "hello".as_bytes());